.. _hpo:

Hyperparameter Optimization
===========================

AgileRL is initially focused on reducing the time taken for training models and hyperparameter optimisation (HPO) by pioneering evolutionary HPO techniques
for reinforcement learning. Evolutionary HPO has been shown to drastically reduce overall training times by automatically converging on optimal hyperparameters,
without requiring numerous training runs.

.. toctree::
   :maxdepth: 1

   mutation
   tournament
